@@ -389,7 +389,7 @@ def get_ww_types_from_features(
             semantic_tags[column] = cutoff_schema.semantic_tags[column]
             origins[column] = "base"
 
-    if entityset.dataframe_type in (Library.DASK.value, Library.SPARK.value):
+    if entityset.dataframe_type in (Library.DASK, Library.SPARK):
         target_dataframe_name = features[0].dataframe_name
         table_schema = entityset[target_dataframe_name].ww.schema
         index_col = table_schema.index
