@@ -19,9 +19,11 @@ class TestUpperCaseWordCount:
             dtype="string",
         )
         primitive_func = self.primitive().get_function()
-        answers = pd.Series([2.0, 1.0, 2.0, 3.0, 1.0])
+        answers = pd.Series([2, 1, 2, 3, 1], dtype="Int64")
         pd.testing.assert_series_equal(
-            primitive_func(x), answers, check_names=False, check_dtype=False
+            primitive_func(x).astype("Int64"),
+            answers,
+            check_names=False,
         )
 
     def test_nan(self):
@@ -34,7 +36,9 @@ class TestUpperCaseWordCount:
             dtype="string",
         )
         primitive_func = self.primitive().get_function()
-        answers = pd.Series([pd.NA, 0.0, 2.0])
+        answers = pd.Series([pd.NA, 0, 2], dtype="Int64")
         pd.testing.assert_series_equal(
-            primitive_func(x), answers, check_names=False, check_dtype=False
+            primitive_func(x).astype("Int64"),
+            answers,
+            check_names=False,
         )
