@@ -8,7 +8,7 @@ from woodwork.logical_types import (
     NaturalLanguage,
 )
 
-import featuretools as ft
+from featuretools import dfs
 from featuretools.entityset import EntitySet
 from featuretools.utils.gen_utils import import_or_none
 
@@ -38,34 +38,43 @@ def test_single_table_spark_entityset():
                 pd.to_datetime("2017-08-25"),
             ],
             "strings": ["I am a string", "23", "abcdef ghijk", ""],
-        }
+        },
     )
     values_dd = ps.from_pandas(df)
     ltypes = {"values": Integer, "dates": Datetime, "strings": NaturalLanguage}
     spark_es.add_dataframe(
-        dataframe_name="data", dataframe=values_dd, index="id", logical_types=ltypes
+        dataframe_name="data",
+        dataframe=values_dd,
+        index="id",
+        logical_types=ltypes,
     )
 
-    spark_fm, _ = ft.dfs(
+    spark_fm, _ = dfs(
         entityset=spark_es,
         target_dataframe_name="data",
         trans_primitives=primitives_list,
     )
 
-    pd_es = ft.EntitySet(id="pd_es")
+    pd_es = EntitySet(id="pd_es")
     pd_es.add_dataframe(
-        dataframe_name="data", dataframe=df, index="id", logical_types=ltypes
+        dataframe_name="data",
+        dataframe=df,
+        index="id",
+        logical_types=ltypes,
     )
 
-    fm, _ = ft.dfs(
-        entityset=pd_es, target_dataframe_name="data", trans_primitives=primitives_list
+    fm, _ = dfs(
+        entityset=pd_es,
+        target_dataframe_name="data",
+        trans_primitives=primitives_list,
     )
 
     spark_fm = spark_fm.to_pandas().astype({"id": "int64"})
     spark_computed_fm = spark_fm.set_index("id").loc[fm.index][fm.columns]
     # Spark dtypes are different for categorical - set the pandas fm to have the same dtypes before comparing
     pd.testing.assert_frame_equal(
-        fm.astype(spark_computed_fm.dtypes), spark_computed_fm
+        fm.astype(spark_computed_fm.dtypes),
+        spark_computed_fm,
     )
 
 
@@ -92,7 +101,7 @@ def test_single_table_spark_entityset_ids_not_sorted():
                 pd.to_datetime("2017-08-25"),
             ],
             "strings": ["I am a string", "23", "abcdef ghijk", ""],
-        }
+        },
     )
     values_dd = ps.from_pandas(df)
     ltypes = {
@@ -101,29 +110,38 @@ def test_single_table_spark_entityset_ids_not_sorted():
         "strings": NaturalLanguage,
     }
     spark_es.add_dataframe(
-        dataframe_name="data", dataframe=values_dd, index="id", logical_types=ltypes
+        dataframe_name="data",
+        dataframe=values_dd,
+        index="id",
+        logical_types=ltypes,
     )
 
-    spark_fm, _ = ft.dfs(
+    spark_fm, _ = dfs(
         entityset=spark_es,
         target_dataframe_name="data",
         trans_primitives=primitives_list,
     )
 
-    pd_es = ft.EntitySet(id="pd_es")
+    pd_es = EntitySet(id="pd_es")
     pd_es.add_dataframe(
-        dataframe_name="data", dataframe=df, index="id", logical_types=ltypes
+        dataframe_name="data",
+        dataframe=df,
+        index="id",
+        logical_types=ltypes,
     )
 
-    fm, _ = ft.dfs(
-        entityset=pd_es, target_dataframe_name="data", trans_primitives=primitives_list
+    fm, _ = dfs(
+        entityset=pd_es,
+        target_dataframe_name="data",
+        trans_primitives=primitives_list,
     )
 
     spark_fm = spark_fm.to_pandas().astype({"id": "int64"})
     spark_computed_fm = spark_fm.set_index("id").loc[fm.index]
     # Spark dtypes are different for categorical - set the pandas fm to have the same dtypes before comparing
     pd.testing.assert_frame_equal(
-        fm.astype(spark_computed_fm.dtypes), spark_computed_fm
+        fm.astype(spark_computed_fm.dtypes),
+        spark_computed_fm,
     )
 
 
@@ -151,28 +169,34 @@ def test_single_table_spark_entityset_with_instance_ids():
                 pd.to_datetime("2017-08-25"),
             ],
             "strings": ["I am a string", "23", "abcdef ghijk", ""],
-        }
+        },
     )
 
     values_dd = ps.from_pandas(df)
     ltypes = {"values": Integer, "dates": Datetime, "strings": NaturalLanguage}
     spark_es.add_dataframe(
-        dataframe_name="data", dataframe=values_dd, index="id", logical_types=ltypes
+        dataframe_name="data",
+        dataframe=values_dd,
+        index="id",
+        logical_types=ltypes,
     )
 
-    spark_fm, _ = ft.dfs(
+    spark_fm, _ = dfs(
         entityset=spark_es,
         target_dataframe_name="data",
         trans_primitives=primitives_list,
         instance_ids=instance_ids,
     )
 
-    pd_es = ft.EntitySet(id="pd_es")
+    pd_es = EntitySet(id="pd_es")
     pd_es.add_dataframe(
-        dataframe_name="data", dataframe=df, index="id", logical_types=ltypes
+        dataframe_name="data",
+        dataframe=df,
+        index="id",
+        logical_types=ltypes,
     )
 
-    fm, _ = ft.dfs(
+    fm, _ = dfs(
         entityset=pd_es,
         target_dataframe_name="data",
         trans_primitives=primitives_list,
@@ -183,7 +207,8 @@ def test_single_table_spark_entityset_with_instance_ids():
     spark_computed_fm = spark_fm.set_index("id").loc[fm.index]
     # Spark dtypes are different for categorical - set the pandas fm to have the same dtypes before comparing
     pd.testing.assert_frame_equal(
-        fm.astype(spark_computed_fm.dtypes), spark_computed_fm
+        fm.astype(spark_computed_fm.dtypes),
+        spark_computed_fm,
     )
 
 
@@ -210,27 +235,33 @@ def test_single_table_spark_entityset_single_cutoff_time():
                 pd.to_datetime("2017-08-25"),
             ],
             "strings": ["I am a string", "23", "abcdef ghijk", ""],
-        }
+        },
     )
     values_dd = ps.from_pandas(df)
     ltypes = {"values": Integer, "dates": Datetime, "strings": NaturalLanguage}
     spark_es.add_dataframe(
-        dataframe_name="data", dataframe=values_dd, index="id", logical_types=ltypes
+        dataframe_name="data",
+        dataframe=values_dd,
+        index="id",
+        logical_types=ltypes,
     )
 
-    spark_fm, _ = ft.dfs(
+    spark_fm, _ = dfs(
         entityset=spark_es,
         target_dataframe_name="data",
         trans_primitives=primitives_list,
         cutoff_time=pd.Timestamp("2019-01-05 04:00"),
     )
 
-    pd_es = ft.EntitySet(id="pd_es")
+    pd_es = EntitySet(id="pd_es")
     pd_es.add_dataframe(
-        dataframe_name="data", dataframe=df, index="id", logical_types=ltypes
+        dataframe_name="data",
+        dataframe=df,
+        index="id",
+        logical_types=ltypes,
     )
 
-    fm, _ = ft.dfs(
+    fm, _ = dfs(
         entityset=pd_es,
         target_dataframe_name="data",
         trans_primitives=primitives_list,
@@ -241,7 +272,8 @@ def test_single_table_spark_entityset_single_cutoff_time():
     spark_computed_fm = spark_fm.set_index("id").loc[fm.index]
     # Spark dtypes are different for categorical - set the pandas fm to have the same dtypes before comparing
     pd.testing.assert_frame_equal(
-        fm.astype(spark_computed_fm.dtypes), spark_computed_fm
+        fm.astype(spark_computed_fm.dtypes),
+        spark_computed_fm,
     )
 
 
@@ -267,7 +299,7 @@ def test_single_table_spark_entityset_cutoff_time_df():
                 pd.to_datetime("2019-01-01"),
             ],
             "strings": ["I am a string", "23", "abcdef ghijk"],
-        }
+        },
     )
     values_dd = ps.from_pandas(df)
     ltypes = {"values": IntegerNullable, "dates": Datetime, "strings": NaturalLanguage}
@@ -288,17 +320,18 @@ def test_single_table_spark_entityset_cutoff_time_df():
     ]
     labels = [True, False, True, False]
     cutoff_times = pd.DataFrame(
-        {"id": ids, "time": times, "labels": labels}, columns=["id", "time", "labels"]
+        {"id": ids, "time": times, "labels": labels},
+        columns=["id", "time", "labels"],
     )
 
-    spark_fm, _ = ft.dfs(
+    spark_fm, _ = dfs(
         entityset=spark_es,
         target_dataframe_name="data",
         trans_primitives=primitives_list,
         cutoff_time=cutoff_times,
     )
 
-    pd_es = ft.EntitySet(id="pd_es")
+    pd_es = EntitySet(id="pd_es")
     pd_es.add_dataframe(
         dataframe_name="data",
         dataframe=df,
@@ -307,7 +340,7 @@ def test_single_table_spark_entityset_cutoff_time_df():
         logical_types=ltypes,
     )
 
-    fm, _ = ft.dfs(
+    fm, _ = dfs(
         entityset=pd_es,
         target_dataframe_name="data",
         trans_primitives=primitives_list,
@@ -324,7 +357,9 @@ def test_single_table_spark_entityset_cutoff_time_df():
             fm[column] = fm[column].astype("Int64").astype("string")
 
     pd.testing.assert_frame_equal(
-        fm.astype(spark_fm.dtypes), spark_fm, check_dtype=False
+        fm.astype(spark_fm.dtypes),
+        spark_fm,
+        check_dtype=False,
     )
 
 
@@ -341,7 +376,7 @@ def test_single_table_spark_entityset_dates_not_sorted():
                 pd.to_datetime("2019-01-01"),
                 pd.to_datetime("2017-08-25"),
             ],
-        }
+        },
     )
 
     primitives_list = ["absolute", "is_weekend", "year", "day"]
@@ -358,14 +393,14 @@ def test_single_table_spark_entityset_dates_not_sorted():
         logical_types=ltypes,
     )
 
-    spark_fm, _ = ft.dfs(
+    spark_fm, _ = dfs(
         entityset=spark_es,
         target_dataframe_name="data",
         trans_primitives=primitives_list,
         max_depth=1,
     )
 
-    pd_es = ft.EntitySet(id="pd_es")
+    pd_es = EntitySet(id="pd_es")
     pd_es.add_dataframe(
         dataframe_name="data",
         dataframe=df,
@@ -374,7 +409,7 @@ def test_single_table_spark_entityset_dates_not_sorted():
         logical_types=ltypes,
     )
 
-    fm, _ = ft.dfs(
+    fm, _ = dfs(
         entityset=pd_es,
         target_dataframe_name="data",
         trans_primitives=primitives_list,
@@ -391,13 +426,23 @@ def test_spark_entityset_secondary_time_index():
     log_df = pd.DataFrame()
     log_df["id"] = [0, 1, 2, 3]
     log_df["scheduled_time"] = pd.to_datetime(
-        ["2019-01-01", "2019-01-01", "2019-01-01", "2019-01-01"]
+        ["2019-01-01", "2019-01-01", "2019-01-01", "2019-01-01"],
     )
     log_df["departure_time"] = pd.to_datetime(
-        ["2019-02-01 09:00", "2019-02-06 10:00", "2019-02-12 10:00", "2019-03-01 11:30"]
+        [
+            "2019-02-01 09:00",
+            "2019-02-06 10:00",
+            "2019-02-12 10:00",
+            "2019-03-01 11:30",
+        ],
     )
     log_df["arrival_time"] = pd.to_datetime(
-        ["2019-02-01 11:23", "2019-02-06 12:45", "2019-02-12 13:53", "2019-03-01 14:07"]
+        [
+            "2019-02-01 11:23",
+            "2019-02-06 12:45",
+            "2019-02-12 13:53",
+            "2019-03-01 14:07",
+        ],
     )
     log_df["delay"] = [-2, 10, 60, 0]
     log_df["flight_id"] = [0, 1, 0, 1]
@@ -408,8 +453,8 @@ def test_spark_entityset_secondary_time_index():
     flights_df["origin"] = ["BOS", "LAX", "BOS", "LAX"]
     flights_spark = ps.from_pandas(flights_df)
 
-    pd_es = ft.EntitySet("flights")
-    spark_es = ft.EntitySet("flights_spark")
+    pd_es = EntitySet("flights")
+    spark_es = EntitySet("flights_spark")
 
     log_ltypes = {
         "scheduled_time": Datetime,
@@ -453,7 +498,7 @@ def test_spark_entityset_secondary_time_index():
     cutoff_df["id"] = [0, 1, 1]
     cutoff_df["time"] = pd.to_datetime(["2019-02-02", "2019-02-02", "2019-02-20"])
 
-    fm, _ = ft.dfs(
+    fm, _ = dfs(
         entityset=pd_es,
         target_dataframe_name="logs",
         cutoff_time=cutoff_df,
@@ -461,7 +506,7 @@ def test_spark_entityset_secondary_time_index():
         trans_primitives=["month"],
     )
 
-    spark_fm, _ = ft.dfs(
+    spark_fm, _ = dfs(
         entityset=spark_es,
         target_dataframe_name="logs",
         cutoff_time=cutoff_df,
@@ -482,5 +527,8 @@ def test_spark_entityset_secondary_time_index():
             fm[column] = fm[column].astype("Int64").astype("string")
 
     pd.testing.assert_frame_equal(
-        fm, spark_fm, check_categorical=False, check_dtype=False
+        fm,
+        spark_fm,
+        check_categorical=False,
+        check_dtype=False,
     )
